import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { ButtonIcon, IconButton } from '../Button';

var SummaryDetail = function SummaryDetail(_ref) {
  var children = _ref.children,
      isOpen = _ref.isOpen,
      iconButtonClassName = _ref.iconButtonClassName,
      onOpen = _ref.onOpen,
      title = _ref.title,
      renderTitle = _ref.renderTitle;
  return React.createElement("div", {
    className: cx('slds-summary-detail', {
      'slds-is-open': isOpen
    })
  }, onOpen && React.createElement(IconButton, {
    onClick: onOpen,
    className: cx('slds-m-right_x-small', iconButtonClassName)
  }, React.createElement(ButtonIcon, {
    className: "slds-summary-detail__action-icon",
    icon: "switch",
    sprite: "utility"
  })), React.createElement("div", null, React.createElement("div", {
    className: "slds-summary-detail__title"
  }, renderTitle(title)), children && React.createElement("div", {
    "aria-hidden": !isOpen,
    className: "slds-summary-detail__content"
  }, children({
    isOpen: isOpen
  }))));
};

SummaryDetail.defaultProps = {
  children: null,
  isOpen: false,
  onOpen: null,
  renderTitle: function renderTitle(title) {
    return React.createElement("h3", {
      className: "slds-text-heading_small slds-truncate"
    }, title);
  },
  iconButtonClassName: null
};
SummaryDetail.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Triggered on open icon and title click
   */
  onOpen: PropTypes.func,

  /**
   * Whether the content is expanded
   */
  isOpen: PropTypes.bool,

  /**
   * Function that renders the content. Takes { isOpen } as arguments
   */
  children: PropTypes.func,

  /**
   * Title to be used by the renderTitle function
   */
  title: PropTypes.string.isRequired,

  /**
   * Renders custom title markup if provided. Receives title as an argument
   */
  renderTitle: PropTypes.func,

  /**
   * Additional className for the expand icon
   */
  iconButtonClassName: PropTypes.string
} : {};
export default SummaryDetail;